module FundRaise

require_relative '../../lib/fund_raise/project'

describe Project do

  before do 
    $stdout = StringIO.new
    @initial_funding = 150
    @target = 3000
    @project = Project.new("Project LMN", @target, @initial_funding)
  end

  it "has an initial default funding of 0" do
    @project = Project.new("Project LMN", @target)
    expect(@project.current_funding).to eq(0)
  end

  it "increased funds by 25 when funds are added" do
    @project.add_funds
    expect(@project.current_funding).to eq(@initial_funding + 25)
  end

  it "decreased funds by 15 when funds are removed" do
    @project.remove_funds
    expect(@project.current_funding).to eq(@initial_funding - 15)
  end

  it "shows funding outstanding" do
    @project.add_funds(50)
    expect(@project.needed_funding).to eq(@target - @initial_funding - 50)
  end

  it "has an initial target amount" do
    @project = Project.new("Project LMN")
    expect(@project.target_funding).should_not eq(0)
  end

  it "project is fully funded" do
    @project.remove_funds(@initial_funding)
    @project.add_funds(@target)
    expect(@project.fully_funded?).to eq(true)
  end

  it "project is not fully funded" do
    @project.remove_funds(@initial_funding)
    @project.add_funds(@target-1)
    expect(@project.fully_funded?).to eq(false)
  end
end
end
